<?php

namespace Litepci\Pricebook\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepci\Pricebook\Http\Requests\PricebookserviceRequest;
use Litepci\Pricebook\Interfaces\PricebookserviceRepositoryInterface;
use Litepci\Pricebook\Models\Pricebookservice;

/**
 * Resource controller class for pricebookservice.
 */
class PricebookserviceResourceController extends BaseController
{

    /**
     * Initialize pricebookservice resource controller.
     *
     * @param type PricebookserviceRepositoryInterface $pricebookservice
     *
     * @return null
     */
    public function __construct(PricebookserviceRepositoryInterface $pricebookservice)
    {
        parent::__construct();
        $this->repository = $pricebookservice;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepci\Pricebook\Repositories\Criteria\PricebookserviceResourceCriteria::class);
    }

    /**
     * Display a list of pricebookservice.
     *
     * @return Response
     */
    public function index(PricebookserviceRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepci\Pricebook\Repositories\Presenter\PricebookservicePresenter::class)
                ->$function();
        }

        $pricebookservices = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('pricebook::pricebookservice.names'))
            ->view('pricebook::pricebookservice.index', true)
            ->data(compact('pricebookservices', 'view'))
            ->output();
    }

    /**
     * Display pricebookservice.
     *
     * @param Request $request
     * @param Model   $pricebookservice
     *
     * @return Response
     */
    public function show(PricebookserviceRequest $request, Pricebookservice $pricebookservice)
    {

        if ($pricebookservice->exists) {
            $view = 'pricebook::pricebookservice.show';
        } else {
            $view = 'pricebook::pricebookservice.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('pricebook::pricebookservice.name'))
            ->data(compact('pricebookservice'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new pricebookservice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PricebookserviceRequest $request)
    {

        $pricebookservice = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('pricebook::pricebookservice.name')) 
            ->view('pricebook::pricebookservice.create', true) 
            ->data(compact('pricebookservice'))
            ->output();
    }

    /**
     * Create new pricebookservice.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PricebookserviceRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $pricebookservice                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('pricebook::pricebookservice.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('pricebook/pricebookservice/' . $pricebookservice->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/pricebook/pricebookservice'))
                ->redirect();
        }

    }

    /**
     * Show pricebookservice for editing.
     *
     * @param Request $request
     * @param Model   $pricebookservice
     *
     * @return Response
     */
    public function edit(PricebookserviceRequest $request, Pricebookservice $pricebookservice)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('pricebook::pricebookservice.name'))
            ->view('pricebook::pricebookservice.edit', true)
            ->data(compact('pricebookservice'))
            ->output();
    }

    /**
     * Update the pricebookservice.
     *
     * @param Request $request
     * @param Model   $pricebookservice
     *
     * @return Response
     */
    public function update(PricebookserviceRequest $request, Pricebookservice $pricebookservice)
    {
        try {
            $attributes = $request->all();

            $pricebookservice->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('pricebook::pricebookservice.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('pricebook/pricebookservice/' . $pricebookservice->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('pricebook/pricebookservice/' . $pricebookservice->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the pricebookservice.
     *
     * @param Model   $pricebookservice
     *
     * @return Response
     */
    public function destroy(PricebookserviceRequest $request, Pricebookservice $pricebookservice)
    {
        try {

            $pricebookservice->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('pricebook::pricebookservice.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('pricebook/pricebookservice/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('pricebook/pricebookservice/' . $pricebookservice->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple pricebookservice.
     *
     * @param Model   $pricebookservice
     *
     * @return Response
     */
    public function delete(PricebookserviceRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('pricebook::pricebookservice.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('pricebook/pricebookservice'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/pricebook/pricebookservice'))
                ->redirect();
        }

    }

    /**
     * Restore deleted pricebookservices.
     *
     * @param Model   $pricebookservice
     *
     * @return Response
     */
    public function restore(PricebookserviceRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('pricebook::pricebookservice.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/pricebook/pricebookservice'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/pricebook/pricebookservice/'))
                ->redirect();
        }

    }

}
