<?php

namespace Litepci\Pricebook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Pricebook\Models\Pricebookservice;

class PricebookservicePolicy
{

    /**
     * Determine if the given user can view the pricebookservice.
     *
     * @param UserPolicy $user
     * @param Pricebookservice $pricebookservice
     *
     * @return bool
     */
    public function view(UserPolicy $user, Pricebookservice $pricebookservice)
    {
        if ($user->canDo('pricebook.pricebookservice.view') && $user->isAdmin()) {
            return true;
        }

        return $pricebookservice->user_id == user_id() && $pricebookservice->user_type == user_type();
    }

    /**
     * Determine if the given user can create a pricebookservice.
     *
     * @param UserPolicy $user
     * @param Pricebookservice $pricebookservice
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('pricebook.pricebookservice.create');
    }

    /**
     * Determine if the given user can update the given pricebookservice.
     *
     * @param UserPolicy $user
     * @param Pricebookservice $pricebookservice
     *
     * @return bool
     */
    public function update(UserPolicy $user, Pricebookservice $pricebookservice)
    {
        if ($user->canDo('pricebook.pricebookservice.edit') && $user->isAdmin()) {
            return true;
        }

        return $pricebookservice->user_id == user_id() && $pricebookservice->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given pricebookservice.
     *
     * @param UserPolicy $user
     * @param Pricebookservice $pricebookservice
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Pricebookservice $pricebookservice)
    {
        return $pricebookservice->user_id == user_id() && $pricebookservice->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given pricebookservice.
     *
     * @param UserPolicy $user
     * @param Pricebookservice $pricebookservice
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Pricebookservice $pricebookservice)
    {
        if ($user->canDo('pricebook.pricebookservice.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given pricebookservice.
     *
     * @param UserPolicy $user
     * @param Pricebookservice $pricebookservice
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Pricebookservice $pricebookservice)
    {
        if ($user->canDo('pricebook.pricebookservice.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
