<?php

namespace Litepci\Pricebook\Providers;

use Illuminate\Support\ServiceProvider;

class PricebookServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'pricebook');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'pricebook');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerPricebook();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerPricebook()
    {
        $this->app->bind('pricebook', function($app) {
            return new Pricebook($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Pricebook', 'Lavalite\Pricebook\Facades\Pricebook');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litepci.pricebook', function ($app) {
            return $this->app->make('Litepci\Pricebook\Pricebook');
        });

                // Bind Pricebookservice to repository
        $this->app->bind(
            'Litepci\Pricebook\Interfaces\PricebookserviceRepositoryInterface',
            \Litepci\Pricebook\Repositories\Eloquent\PricebookserviceRepository::class
        );

        $this->app->register(\Litepci\Pricebook\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepci\Pricebook\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and pricebook's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepci.pricebook'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakePricebook::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepci.pricebook'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepci/pricebook.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/pricebook')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/pricebook')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
